package svc

import (
	"applet/app/admin/md"
	"applet/app/db"
	"applet/app/db/model"
	enum2 "applet/app/enum"
	"applet/app/utils"
	"applet/app/utils/logx"
	"errors"
	"fmt"
	"strings"
	"time"
)

func CentralKitchenForSchoolUserUpdate(req md.CentralKitchenForSchoolUserUpdateReq) (err error) {
	//1、删除当前用户&&当前单位下的所有身份对应的 `class_with_user` 记录
	var userIdentities []model.UserIdentity
	err = db.Db.Where("uid =? AND enterprise_id =?", req.Uid, req.EnterpriseId).Find(&userIdentities)
	if err != nil {
		return
	}
	var userIdentityIds []int
	for _, v := range userIdentities {
		userIdentityIds = append(userIdentityIds, v.Id)
	}
	_, err = db.Db.In("user_identity_id", userIdentityIds).Delete(model.ClassWithUser{})
	if err != nil {
		return
	}

	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()

	//2、新增 / 编辑 数据
	now := time.Now()
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(req.Uid)

	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()

	var newUserIdentityIds []string
	for _, v := range req.BindUserIdentities {
		if v.UserIdentityId == 0 {
			// 新增
			if v.ClassId == -1 {
				//TODO::为老师身份
				_, err3 := userIdentityDb.UserIdentityInsertBySession(session, &model.UserIdentity{
					Uid:          req.Uid,
					Name:         v.Name,
					IdNo:         v.IdNo,
					Kind:         enum2.UserIdentityKindForCommon,
					Identity:     enum2.UserIdentityForCentralKitchenForTeacher,
					EnterpriseId: req.EnterpriseId,
					State:        enum2.UserIdentityStateForNormal,
					Memo:         "",
					CreateAt:     now.Format("2006-01-02 15:04:05"),
					UpdateAt:     now.Format("2006-01-02 15:04:05"),
				})
				if err3 != nil {
					_ = session.Rollback()
					return err3
				}
				continue
			}

			insertId, err1 := userIdentityDb.UserIdentityInsertBySession(session, &model.UserIdentity{
				Uid:          req.Uid,
				Name:         v.Name,
				IdNo:         v.IdNo,
				Kind:         enum2.UserIdentityKindForCommon,
				Identity:     enum2.UserIdentityForCentralKitchenForStudent,
				EnterpriseId: req.EnterpriseId,
				State:        enum2.UserIdentityStateForNormal,
				Memo:         "",
				CreateAt:     now.Format("2006-01-02 15:04:05"),
				UpdateAt:     now.Format("2006-01-02 15:04:05"),
			})
			if err1 != nil {
				_ = session.Rollback()
				return err1
			}

			_, err2 := classWithUserDb.ClassWithUserInsertBySession(session, &model.ClassWithUser{
				UserIdentityId: insertId,
				ClassId:        v.ClassId,
				CreateAt:       now.Format("2006-01-02 15:04:05"),
				UpdateAt:       now.Format("2006-01-02 15:04:05"),
			})
			if err2 != nil {
				_ = session.Rollback()
				return err1
			}

			newUserIdentityIds = append(newUserIdentityIds, utils.IntToStr(insertId))
		} else {
			//编辑
			identity, err2 := userIdentityDb.GetUserIdentity(v.UserIdentityId)
			if err != nil {
				_ = session.Rollback()
				return err2
			}
			if identity == nil {
				_ = session.Rollback()
				return errors.New("未查询到对应的身份信息记录")
			}
			identity.IdNo = v.IdNo
			identity.Name = v.Name
			if v.ClassId == -1 {
				//TODO::为老师身份
				identity.Identity = enum2.UserIdentityForCentralKitchenForTeacher
			} else {
				identity.Identity = enum2.UserIdentityForCentralKitchenForStudent
				_, err3 := classWithUserDb.ClassWithUserInsertBySession(session, &model.ClassWithUser{
					UserIdentityId: v.UserIdentityId,
					ClassId:        v.ClassId,
					CreateAt:       now.Format("2006-01-02 15:04:05"),
					UpdateAt:       now.Format("2006-01-02 15:04:05"),
				})
				if err3 != nil {
					_ = session.Rollback()
					return err3
				}
			}
			_, err3 := userIdentityDb.UserIdentityUpdateBySession(session, v.UserIdentityId, identity, "id_no", "name", "identity")
			if err3 != nil {
				_ = session.Rollback()
				return err3
			}

			newUserIdentityIds = append(newUserIdentityIds, utils.IntToStr(v.UserIdentityId))
		}
	}

	//3、删除需要删除的身份信息
	for _, v := range userIdentityIds {
		if !utils.InArr(utils.IntToStr(v), newUserIdentityIds) {
			_, err = session.Where("id = ?", v).Delete(model.UserIdentity{})
			if err != nil {
				_ = session.Rollback()
				return
			}
		}
	}
	return session.Commit()
}

func CentralKitchenForSchoolUserUpdateV2(req md.CentralKitchenForSchoolUserUpdateReqV2) (err error) {
	//1、删除当前用户&&央厨学校下的所有身份对应的 `class_with_user` 记录
	var userIdentities []model.UserIdentity
	err = db.Db.Where("uid =?", req.Uid).And("identity =? or identity =?", enum2.UserIdentityForCentralKitchenForTeacher, enum2.UserIdentityForCentralKitchenForStudent).Find(&userIdentities)
	if err != nil {
		return
	}
	var userIdentityIds []int
	for _, v := range userIdentities {
		userIdentityIds = append(userIdentityIds, v.Id)
	}
	_, err = db.Db.In("user_identity_id", userIdentityIds).Delete(model.ClassWithUser{})
	if err != nil {
		return
	}

	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()

	//2、新增 / 编辑 数据
	now := time.Now()
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(req.Uid)

	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()

	var newUserIdentityIds []string
	for _, v := range req.BindUserIdentities {
		if v.UserIdentityId == 0 {
			// 新增
			if v.ClassId == -1 {
				//TODO::为老师身份
				_, err3 := userIdentityDb.UserIdentityInsertBySession(session, &model.UserIdentity{
					Uid:          req.Uid,
					Name:         v.Name,
					IdNo:         v.IdNo,
					Kind:         enum2.UserIdentityKindForCommon,
					Identity:     enum2.UserIdentityForCentralKitchenForTeacher,
					EnterpriseId: v.EnterpriseId,
					State:        enum2.UserIdentityStateForNormal,
					Memo:         "",
					CreateAt:     now.Format("2006-01-02 15:04:05"),
					UpdateAt:     now.Format("2006-01-02 15:04:05"),
				})
				if err3 != nil {
					_ = session.Rollback()
					return err3
				}
				continue
			}

			insertId, err1 := userIdentityDb.UserIdentityInsertBySession(session, &model.UserIdentity{
				Uid:          req.Uid,
				Name:         v.Name,
				IdNo:         v.IdNo,
				Kind:         enum2.UserIdentityKindForCommon,
				Identity:     enum2.UserIdentityForCentralKitchenForStudent,
				EnterpriseId: v.EnterpriseId,
				State:        enum2.UserIdentityStateForNormal,
				Memo:         "",
				CreateAt:     now.Format("2006-01-02 15:04:05"),
				UpdateAt:     now.Format("2006-01-02 15:04:05"),
			})
			if err1 != nil {
				_ = session.Rollback()
				return err1
			}

			_, err2 := classWithUserDb.ClassWithUserInsertBySession(session, &model.ClassWithUser{
				UserIdentityId: insertId,
				ClassId:        v.ClassId,
				CreateAt:       now.Format("2006-01-02 15:04:05"),
				UpdateAt:       now.Format("2006-01-02 15:04:05"),
			})
			if err2 != nil {
				_ = session.Rollback()
				return err1
			}

			newUserIdentityIds = append(newUserIdentityIds, utils.IntToStr(insertId))
		} else {
			//编辑
			identity, err2 := userIdentityDb.GetUserIdentity(v.UserIdentityId)
			if err != nil {
				_ = session.Rollback()
				return err2
			}
			if identity == nil {
				_ = session.Rollback()
				return errors.New("未查询到对应的身份信息记录")
			}
			identity.EnterpriseId = v.EnterpriseId
			identity.IdNo = v.IdNo
			identity.Name = v.Name
			if v.ClassId == -1 {
				//TODO::为老师身份
				identity.Identity = enum2.UserIdentityForCentralKitchenForTeacher
			} else {
				_, err3 := classWithUserDb.ClassWithUserInsertBySession(session, &model.ClassWithUser{
					UserIdentityId: v.UserIdentityId,
					ClassId:        v.ClassId,
					CreateAt:       now.Format("2006-01-02 15:04:05"),
					UpdateAt:       now.Format("2006-01-02 15:04:05"),
				})
				if err3 != nil {
					_ = session.Rollback()
					return err3
				}
			}
			_, err3 := userIdentityDb.UserIdentityUpdateBySession(session, v.UserIdentityId, identity, "id_no", "enterprise_id", "name", "identity")
			if err3 != nil {
				_ = session.Rollback()
				return err3
			}

			newUserIdentityIds = append(newUserIdentityIds, utils.IntToStr(v.UserIdentityId))
		}
	}

	//3、删除需要删除的身份信息
	for _, v := range userIdentityIds {
		if !utils.InArr(utils.IntToStr(v), newUserIdentityIds) {
			_, err = session.Where("id = ?", v).Delete(model.UserIdentity{})
			if err != nil {
				_ = session.Rollback()
				return
			}
		}
	}
	return session.Commit()
}

func CentralKitchenForSchoolUserDelete(req md.CentralKitchenForSchoolUserDeleteReq) (err error) {
	//1、删除 class_with_user
	var userIdentities []model.UserIdentity
	err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("uid", req.Uids).Find(&userIdentities)
	if err != nil {
		return
	}
	var userIdentityIds []int
	for _, v := range userIdentities {
		userIdentityIds = append(userIdentityIds, v.Id)
	}
	_, err = db.Db.In("user_identity_id", userIdentityIds).Delete(model.ClassWithUser{})
	if err != nil {
		return
	}

	//2、删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("uid", req.Uids).Delete(model.UserIdentity{})
	if err != nil {
		return
	}
	return
}

func CentralKitchenForSchoolUserDeleteV2(req md.CentralKitchenForSchoolUserDeleteReq) (err error) {
	//1、删除 class_with_user
	var userIdentities []model.UserIdentity
	err = db.Db.Where("identity =? or identity =?", enum2.UserIdentityForCentralKitchenForTeacher, enum2.UserIdentityForCentralKitchenForStudent).
		In("uid", req.Uids).Find(&userIdentities)
	if err != nil {
		return
	}
	var userIdentityIds []int
	for _, v := range userIdentities {
		userIdentityIds = append(userIdentityIds, v.Id)
	}
	_, err = db.Db.In("user_identity_id", userIdentityIds).Delete(model.ClassWithUser{})
	if err != nil {
		return
	}

	//2、删除 user_identity
	_, err = db.Db.Where("identity =? or identity =?", enum2.UserIdentityForCentralKitchenForTeacher, enum2.UserIdentityForCentralKitchenForStudent).
		In("id", userIdentityIds).
		Delete(model.UserIdentity{})
	if err != nil {
		return
	}
	return
}

func CentralKitchenForSchoolStudentList(req md.CentralKitchenForSchoolStudentListReq) (resp []md.CentralKitchenForSchoolStudentListResp, count int64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return nil, 0, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return nil, 0, err3
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return nil, 0, err4
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}
	sess := db.Db.Where("user_identity.enterprise_id =?", req.EnterpriseId).And("identity =?", enum2.UserIdentityForCentralKitchenForStudent)
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.IdNo != "" {
		sess.And("user_identity.id_no like ?", "%"+req.IdNo+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.UserIdentityWithUser
	count, err = sess.
		Join("LEFT", "user", "user_identity.uid = user.id").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.CentralKitchenForSchoolStudentListResp{
			IdNo:           v.UserIdentity.IdNo,
			ParentPhone:    v.User.Phone,
			Name:           v.UserIdentity.Name,
			Grade:          v.Grade.Name,
			GradeId:        v.Grade.Id,
			Class:          v.Class.Name,
			ClassId:        v.Class.Id,
			UserIdentityId: v.UserIdentity.Id,
		})
	}
	return
}

func CentralKitchenForSchoolTeacherList(req md.CentralKitchenForSchoolTeacherListReq) (resp []md.CentralKitchenForSchoolTeacherListResp, count int64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()

	sess := db.Db.Where("user_identity.enterprise_id =?", req.EnterpriseId).And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.IdNo != "" {
		sess.And("user_identity.id_no like ?", "%"+req.IdNo+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.UserIdentityWithUser
	count, err = sess.
		Join("LEFT", "user", "user_identity.uid = user.id").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.CentralKitchenForSchoolTeacherListResp{
			UserIdentityId: v.UserIdentity.Id,
			IdNo:           v.UserIdentity.IdNo,
			Phone:          v.User.Phone,
			Name:           v.UserIdentity.Name,
		})
	}
	return
}

func CentralKitchenForSchoolStudentUpdate(req md.CentralKitchenForSchoolStudentUpdateReq) (err error) {
	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()

	//1、修改 `user_identity`
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	userIdentity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
	if err != nil {
		return
	}
	if userIdentity == nil {
		return errors.New("未查询到对应记录")
	}
	userIdentity.IdNo = req.IdNo
	userIdentity.Name = req.Name
	_, err = userIdentityDb.UserIdentityUpdate(req.UserIdentityId, userIdentity, "id_no", "name")
	if err != nil {
		return
	}

	//2、更新 `class_with_user`
	_, err = session.Where("user_identity_id =?", req.UserIdentityId).Delete(model.ClassWithUser{})
	if err != nil {
		_ = session.Rollback()
		return
	}

	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	_, err = classWithUserDb.ClassWithUserInsertBySession(session, &model.ClassWithUser{
		UserIdentityId: req.UserIdentityId,
		ClassId:        req.ClassId,
		CreateAt:       time.Now().Format("2006-01-02 15:04:05"),
		UpdateAt:       time.Now().Format("2006-01-02 15:04:05"),
	})

	return session.Commit()
}

func CentralKitchenForSchoolStudentDelete(req md.CentralKitchenForSchoolStudentDeleteReq) (err error) {
	//1、删除 class_with_user
	_, err = db.Db.In("user_identity_id", req.UserIdentityIds).Delete(model.ClassWithUser{})
	if err != nil {
		return
	}

	//2、删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("id", req.UserIdentityIds).Delete(model.UserIdentity{})
	if err != nil {
		return
	}
	return
}

func CentralKitchenForSchoolStudentAdmission(req md.CentralKitchenForSchoolStudentAdmissionReq) (err error) {
	//1、判断 "按年级" / "按班级" 升级
	if req.ClassId != 0 {
		// 删除 class_with_user 记录
		_, err = db.Db.Where("class_id = ?", req.ClassId).Delete(model.ClassWithUser{})
		if err != nil {
			return
		}
	}
	if req.GradeId != 0 {
		// 查找班级记录
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err1 := classDb.FindClass()
		if err1 != nil {
			return err1
		}
		var classesIds []int
		for _, v := range *classes {
			classesIds = append(classesIds, v.Id)
		}

		// 删除 class_with_user 记录
		_, err = db.Db.In("class_id", classesIds).Delete(model.ClassWithUser{})
		if err != nil {
			return
		}
	}

	return
}

func CentralKitchenForSchoolStudentAdmissionByClass(req md.CentralKitchenForSchoolStudentAdmissionByClass) (err error) {
	// 删除 class_with_user 记录
	_, err = db.Db.In("class_id", req.ClassIds).Delete(model.ClassWithUser{})
	return
}

func CentralKitchenForSchoolStudentAdmissionByGrade(req md.CentralKitchenForSchoolStudentAdmissionByGrade) (err error) {
	for _, v := range req.GradeIds {
		// 查找班级记录
		classDb := db.ClassDb{}
		classDb.Set(v)
		classes, err1 := classDb.FindClass()
		if err1 != nil {
			return err1
		}
		var classesIds []int
		for _, v := range *classes {
			classesIds = append(classesIds, v.Id)
		}

		// 删除 class_with_user 记录
		_, err = db.Db.In("class_id", classesIds).Delete(model.ClassWithUser{})
		if err != nil {
			return
		}
	}
	return
}

func CentralKitchenForSchoolStudentAdmissionBySchool(req md.CentralKitchenForSchoolStudentAdmissionBySchool) (err error) {
	for _, v := range req.EnterpriseIds {
		// 查找班级记录
		classDb := db.ClassDb{}
		classDb.Set(0)
		classes, err1 := classDb.FindClassByEnterprise(v)
		if err1 != nil {
			return err1
		}
		var classesIds []int
		for _, v := range *classes {
			classesIds = append(classesIds, v.Id)
		}

		// 删除 class_with_user 记录
		_, err = db.Db.In("class_id", classesIds).Delete(model.ClassWithUser{})
		if err != nil {
			return
		}
	}
	return
}

func CentralKitchenForSchoolOrdList(req md.CentralKitchenForSchoolOrdListReq) (resp []md.CentralKitchenForSchoolOrdListResp, count int64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return nil, 0, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return nil, 0, err3
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return nil, 0, err4
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}

	sess := db.Db.Desc("central_kitchen_for_school_package_ord.id")
	if req.EnterpriseId != 0 {
		sess.And("central_kitchen_for_school_package_ord.enterprise_id =?", req.EnterpriseId)
	}
	if req.IsTeacher != 0 {
		if req.IsTeacher == 1 {
			sess.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
		if req.IsTeacher == 2 {
			sess.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
	}
	if req.StartDate != "" {
		sess.And("central_kitchen_for_school_package_ord.create_at >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess.And("central_kitchen_for_school_package_ord.create_at <= ?", req.EndDate)
	}
	if req.Kind != 0 {
		sess.And("central_kitchen_for_school_package_ord.kind = ?", req.Kind)
	}
	if req.Sate != 0 {
		sess.And("central_kitchen_for_school_package_ord.state = ?", req.Sate)
	}
	if req.OrdSate != 0 {
		sess.And("central_kitchen_for_school_package_ord.ord_state = ?", req.OrdSate)
	}
	if req.OutTradeNo != "" {
		sess.And("central_kitchen_for_school_package_ord.out_trade_no like ?", "%"+req.OutTradeNo+"%")
	}

	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}

	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.CentralKitchenForSchoolPackageOrdWithUserIdentity
	count, err = sess.
		Join("LEFT", "user_identity", "central_kitchen_for_school_package_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.CentralKitchenForSchoolOrdListResp{
			EnterpriseId:     v.UserIdentity.EnterpriseId,
			EnterpriseName:   v.Enterprise.Name,
			Uid:              v.UserIdentity.Uid,
			UserIdentityId:   v.UserIdentity.Id,
			UserIdentityKind: v.UserIdentity.Kind,
			UserIdentityName: v.CentralKitchenForSchoolPackageOrd.UserIdentityName,
			TotalPrice:       v.CentralKitchenForSchoolPackageOrd.TotalPrice,
			Kind:             v.CentralKitchenForSchoolPackageOrd.Kind,
			OutTradeNo:       v.CentralKitchenForSchoolPackageOrd.OutTradeNo,
			TradeNo:          v.CentralKitchenForSchoolPackageOrd.TradeNo,
			State:            v.CentralKitchenForSchoolPackageOrd.State,
			OrdState:         v.CentralKitchenForSchoolPackageOrd.OrdState,
			CreateAt:         v.CentralKitchenForSchoolPackageOrd.CreateAt,
			Phone:            v.User.Phone,
			Name:             v.UserIdentity.Name,
			Grade:            v.Grade.Name,
			GradeId:          v.Grade.Id,
			Class:            v.Class.Name,
			ClassId:          v.Class.Id,
		})
	}
	return
}

func CentralKitchenForSchoolReserveList(req md.CentralKitchenForSchoolReserveListReq) (resp []md.CentralKitchenForSchoolReserveListResp, count int64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return nil, 0, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return nil, 0, err3
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return nil, 0, err4
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}

	var centralKitchenForSchoolUserWithDayIds []string
	if req.StartDate != "" && req.EndDate != "" {
		var m []model.CentralKitchenForSchoolUserWithDay
		if err1 := db.Db.Where("state != ?", enum2.CentralKitchenForSchoolUserWithDayStateForCancel).
			And("date >= ? And date <= ?", req.StartDate, req.EndDate).Asc("date").Find(&m); err != nil {
			return nil, 0, err1
		}
		for _, v := range m {
			centralKitchenForSchoolUserWithDayIds = append(centralKitchenForSchoolUserWithDayIds, v.OrdNo)
		}
	}

	var months []time.Month
	if req.StartDate != "" {
		sDate, _ := time.ParseInLocation("2006-01-02", req.StartDate, time.Local)
		eDate, _ := time.ParseInLocation("2006-01-02", req.EndDate, time.Local)
		_, sMonth, _ := sDate.Date()
		_, eMonth, _ := eDate.Date()
		diffMonth := sMonth - eMonth
		if diffMonth == 0 {
			//TODO::查询一个月
			months = append(months, sMonth)
		} else {
			for i := sMonth; i <= eMonth; i++ {
				months = append(months, i)
			}
		}
	}

	sess := db.Db.
		Desc("central_kitchen_for_school_package_ord_for_reserve.id")
	if req.EnterpriseId != 0 {
		sess.And("central_kitchen_for_school_package_ord_for_reserve.enterprise_id =?", req.EnterpriseId)
	}
	if req.Kind != 0 {
		sess.And("central_kitchen_for_school_package_ord_for_reserve.kind = ?", req.Kind)
	}
	if req.OutTradeNo != "" {
		sess.And("central_kitchen_for_school_package_ord_for_reserve.out_trade_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}

	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}
	if len(centralKitchenForSchoolUserWithDayIds) > 0 {
		sess.In("central_kitchen_for_school_package_ord.out_trade_no", centralKitchenForSchoolUserWithDayIds)
	}
	if len(months) > 0 {
		sess.In("central_kitchen_for_school_package_ord_for_reserve.reserve_month", months)
	}
	var m []*db.CentralKitchenForSchoolPackageOrdForReserveWithUserIdentity
	count, err = sess.
		Join("LEFT", "central_kitchen_for_school_package_ord", "central_kitchen_for_school_package_ord_for_reserve.out_trade_no = central_kitchen_for_school_package_ord.out_trade_no").
		Join("LEFT", "user_identity", "central_kitchen_for_school_package_ord_for_reserve.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = central_kitchen_for_school_package_ord_for_reserve.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	//centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
	//centralKitchenForSchoolUserWithDayDb.Set(0)
	for _, v := range m {
		//var kindList []int
		//if req.Kind != 0 {
		//	kindList = append(kindList, req.Kind)
		//}
		//count1, err1 := centralKitchenForSchoolUserWithDayDb.CountCentralKitchenForSchoolUserWithDayByOrdNoV2(
		//	v.CentralKitchenForSchoolPackageOrdForReserve.OutTradeNo, enum2.CentralKitchenForSchoolUserWithDayStateForCancel,
		//	req.StartDate, req.EndDate, kindList)
		//if err1 != nil {
		//	return nil, 0, err1
		//}
		//if count1 == 0 {
		//	continue
		//}

		//获取当前预定记录下有多少退款记录
		var state = 1
		var stateZh = "已支付"

		centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
		centralKitchenForSchoolUserWithDayDb.Set(0)
		count1, err1 := centralKitchenForSchoolUserWithDayDb.CountCentralKitchenForSchoolUserWithDayByOrdNoV2(v.CentralKitchenForSchoolPackageOrdForReserve.OutTradeNo, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling,
			v.CentralKitchenForSchoolPackageOrdForReserve.MealTimeStart, v.CentralKitchenForSchoolPackageOrdForReserve.MealTimeEnd, v.CentralKitchenForSchoolPackageOrdForReserve.Kind)
		if err1 != nil {
			return nil, 0, err1
		}
		if count1 > 0 {
			state = 2
			stateZh = "退款中"
		} else {
			count2, err2 := centralKitchenForSchoolUserWithDayDb.CountCentralKitchenForSchoolUserWithDayByOrdNoV2(v.CentralKitchenForSchoolPackageOrdForReserve.OutTradeNo, enum2.CentralKitchenForSchoolUserWithDayStateForCancel,
				v.CentralKitchenForSchoolPackageOrdForReserve.MealTimeStart, v.CentralKitchenForSchoolPackageOrdForReserve.MealTimeEnd, v.CentralKitchenForSchoolPackageOrdForReserve.Kind)
			if err1 != nil {
				return nil, 0, err2
			}
			if count2 > 0 {
				state = 3
				stateZh = "部分退款"
				if count2 >= 30 {
					state = 4
					stateZh = "已退款"
				}
				//count3, err3 := centralKitchenForSchoolUserWithDayDb.CountCentralKitchenForSchoolUserWithDayByOrdNoV2(v.CentralKitchenForSchoolPackageOrdForReserve.OutTradeNo, enum2.CentralKitchenForSchoolUserWithDayStateForWait,
				//	v.CentralKitchenForSchoolPackageOrdForReserve.MealTimeStart, v.CentralKitchenForSchoolPackageOrdForReserve.MealTimeEnd, v.CentralKitchenForSchoolPackageOrdForReserve.Kind)
				//if err1 != nil {
				//	return nil, 0, err3
				//}
				//if count3 == 0 {
				//	count4, err4 := centralKitchenForSchoolUserWithDayDb.CountCentralKitchenForSchoolUserWithDayByOrdNoV2(v.CentralKitchenForSchoolPackageOrdForReserve.OutTradeNo, enum2.CentralKitchenForSchoolUserWithDayStateForAlready,
				//		v.CentralKitchenForSchoolPackageOrdForReserve.MealTimeStart, v.CentralKitchenForSchoolPackageOrdForReserve.MealTimeEnd, v.CentralKitchenForSchoolPackageOrdForReserve.Kind)
				//	if err1 != nil {
				//		return nil, 0, err4
				//	}
				//	if count4 == 0 {
				//		state = 4
				//		stateZh = "已退款"
				//	}
				//}
			}
		}

		resp = append(resp, md.CentralKitchenForSchoolReserveListResp{
			Id:               v.CentralKitchenForSchoolPackageOrdForReserve.Id,
			EnterpriseId:     v.UserIdentity.EnterpriseId,
			EnterpriseName:   v.Enterprise.Name,
			Uid:              v.UserIdentity.Uid,
			UserIdentityId:   v.UserIdentity.Id,
			UserIdentityName: v.CentralKitchenForSchoolPackageOrdForReserve.UserIdentityName,
			Kind:             v.CentralKitchenForSchoolPackageOrdForReserve.Kind,
			ReserveMonth:     v.CentralKitchenForSchoolPackageOrdForReserve.ReserveMonth,
			TotalPrice:       v.CentralKitchenForSchoolPackageOrdForReserve.TotalPrice,
			CreateAt:         v.CentralKitchenForSchoolPackageOrdForReserve.CreateAt,
			OutTradeNo:       v.CentralKitchenForSchoolPackageOrd.OutTradeNo,
			Phone:            v.User.Phone,
			Grade:            v.Grade.Name,
			GradeId:          v.Grade.Id,
			Class:            v.Class.Name,
			ClassId:          v.Class.Id,
			State:            state,
			StateZh:          stateZh,
		})
	}
	return
}

func CentralKitchenForSchoolOrdRefund(req md.CentralKitchenForSchoolOrdRefundReq) (err error) {
	//1、查询出所有 `central_kitchen_for_school_user_with_day` 记录
	var m []model.CentralKitchenForSchoolUserWithDay
	centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
	centralKitchenForSchoolUserWithDayDb.Set(0)
	err = centralKitchenForSchoolUserWithDayDb.Db.Where("state =?", enum2.CentralKitchenForSchoolUserWithDayStateForWait).In("id", req.Ids).Find(&m)
	if err != nil {
		return err
	}
	if len(m) > 0 {
		//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
		sql := "update central_kitchen_for_school_user_with_day set state = %d where id In  (%s)"
		idsStr := strings.Join(req.Ids, ",")
		sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr)
		fmt.Println(sql)
		_, err = db.ExecuteOriginalSql(db.Db, sql)
		if err != nil {
			return err
		}

		//3、循环处理数据
		var dealOutTradeNo = map[string]string{}
		var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
		now := time.Now()
		for _, v := range m {
			dealOutTradeNo[v.OrdNo] = v.OrdNo
			//outRequestNo := utils.OrderUUID(v.Uid)
			outRequestNo := ""
			centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
				OutTradeNo:   v.OrdNo,
				OutRequestNo: outRequestNo,
				Uid:          v.Uid,
				IdentityId:   v.IdentityId,
				RecordsId:    v.Id,
				State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
				Amount:       v.Amount,
				Memo:         "",
				CreateAt:     now.Format("2006-01-02 15:04:05"),
				UpdateAt:     now.Format("2006-01-02 15:04:05"),
			})
		}

		//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态(ord_state)
		for _, v := range dealOutTradeNo {
			err1 := JudgePackageOrdOrdState(v)
			if err1 != nil {
				return err1
			}
		}

		//5、新增 `central_kitchen_for_school_user_refund_day` 数据
		centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
		centralKitchenForSchoolUserRefundDayDb.Set(0)
		_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
	}
	return
}

func CentralKitchenForSchoolBatchAskForLeaveBySchool(req md.CentralKitchenForSchoolBatchAskForLeaveReqBySchool) (err error) {
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	for _, v := range req.EnterpriseIds {
		//1、查询学校
		enterprise, err1 := enterpriseDb.GetEnterprise(v)
		if err1 != nil {
			return
		}
		if enterprise == nil {
			return errors.New("未查询到id：【" + utils.IntToStr(v) + "】公司对应记录")
		}

		for _, date := range req.Dates {
			//2、查询出所有 `central_kitchen_for_school_user_with_day` 记录
			var mm []model.CentralKitchenForSchoolUserWithDay
			centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
			centralKitchenForSchoolUserWithDayDb.Set(0)
			if req.IsBreakfast == 1 {
				err = centralKitchenForSchoolUserWithDayDb.Db.Where("enterprise_id =?", v).And("date =?", date).
					And("kind =?", enum2.CentralKitchenForSchoolUserWithDayKindForBreakfast).Find(&mm)
				if err != nil {
					return err
				}
				if len(mm) > 0 {
					var identityIds []string
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						identityIds = append(identityIds, utils.IntToStr(m.IdentityId))
					}
					if len(identityIds) <= 0 {
						//无请假学生
						continue
					}

					//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
					sql := "update central_kitchen_for_school_user_with_day set state = %d where identity_id In (%s) and date = '%s' and kind = %d and state = %d"
					idsStr := strings.Join(identityIds, ",")
					sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr, date, enum2.CentralKitchenForSchoolUserWithDayKindForBreakfast, enum2.CentralKitchenForSchoolUserWithDayStateForWait)
					fmt.Println(sql)
					_, err = db.ExecuteOriginalSql(db.Db, sql)
					if err != nil {
						return err
					}

					//3、循环处理数据
					var dealOutTradeNo = map[string]string{}
					var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
					now := time.Now()
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						dealOutTradeNo[m.OrdNo] = m.OrdNo
						//outRequestNo := utils.OrderUUID(m.Uid)
						outRequestNo := ""
						centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
							OutTradeNo:   m.OrdNo,
							OutRequestNo: outRequestNo,
							Uid:          m.Uid,
							IdentityId:   m.IdentityId,
							RecordsId:    m.Id,
							State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
							Amount:       m.Amount,
							Memo:         "",
							CreateAt:     now.Format("2006-01-02 15:04:05"),
							UpdateAt:     now.Format("2006-01-02 15:04:05"),
						})
					}

					//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态 (ord_state)
					for _, vv := range dealOutTradeNo {
						err2 := JudgePackageOrdOrdState(vv)
						if err2 != nil {
							return err2
						}
					}

					//5、新增 `central_kitchen_for_school_user_refund_day` 数据
					centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
					centralKitchenForSchoolUserRefundDayDb.Set(0)
					_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
					if err != nil {
						return err
					}
				}
			}

			if req.IsLunch == 1 {
				err = centralKitchenForSchoolUserWithDayDb.Db.Where("enterprise_id =?", v).And("date =?", date).
					And("kind =?", enum2.CentralKitchenForSchoolUserWithDayKindForLunch).Find(&mm)
				if err != nil {
					return err
				}

				if len(mm) > 0 {
					var identityIds []string
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						identityIds = append(identityIds, utils.IntToStr(m.IdentityId))
					}
					if len(identityIds) <= 0 {
						//无请假学生
						continue
					}

					//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
					sql := "update central_kitchen_for_school_user_with_day set state = %d where identity_id In (%s) and date = '%s' and kind = %d and state = %d"
					idsStr := strings.Join(identityIds, ",")
					sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr, date, enum2.CentralKitchenForSchoolUserWithDayKindForLunch, enum2.CentralKitchenForSchoolUserWithDayStateForWait)
					fmt.Println(sql)
					_, err = db.ExecuteOriginalSql(db.Db, sql)
					if err != nil {
						return err
					}

					//3、循环处理数据
					var dealOutTradeNo = map[string]string{}
					var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
					now := time.Now()
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						dealOutTradeNo[m.OrdNo] = m.OrdNo
						//outRequestNo := utils.OrderUUID(m.Uid)
						outRequestNo := ""
						centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
							OutTradeNo:   m.OrdNo,
							OutRequestNo: outRequestNo,
							Uid:          m.Uid,
							IdentityId:   m.IdentityId,
							RecordsId:    m.Id,
							State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
							Amount:       m.Amount,
							Memo:         "",
							CreateAt:     now.Format("2006-01-02 15:04:05"),
							UpdateAt:     now.Format("2006-01-02 15:04:05"),
						})
					}

					//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态 (ord_state)
					go func() {
						for _, vv := range dealOutTradeNo {
							err2 := JudgePackageOrdOrdState(vv)
							if err2 != nil {
								logx.Error(err2)
								println("<<<<JudgePackageOrdOrdState>>>>>Error:::", err2.Error())
							}
						}
					}()

					//5、新增 `central_kitchen_for_school_user_refund_day` 数据
					centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
					centralKitchenForSchoolUserRefundDayDb.Set(0)
					_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
					if err != nil {
						return err
					}
				}
			}

			if req.IsDinner == 1 {
				err = centralKitchenForSchoolUserWithDayDb.Db.Where("enterprise_id =?", v).And("date =?", date).
					And("kind =?", enum2.CentralKitchenForSchoolUserWithDayKindForDinner).Find(&mm)
				if err != nil {
					return err
				}

				if len(mm) > 0 {
					var identityIds []string
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						identityIds = append(identityIds, utils.IntToStr(m.IdentityId))
					}
					if len(identityIds) <= 0 {
						//无请假学生
						continue
					}

					//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
					sql := "update central_kitchen_for_school_user_with_day set state = %d where identity_id In (%s) and date = '%s' and kind = %d and state = %d"
					idsStr := strings.Join(identityIds, ",")
					sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr, date, enum2.CentralKitchenForSchoolUserWithDayKindForDinner, enum2.CentralKitchenForSchoolUserWithDayStateForWait)
					fmt.Println(sql)
					_, err = db.ExecuteOriginalSql(db.Db, sql)
					if err != nil {
						return err
					}

					//3、循环处理数据
					var dealOutTradeNo = map[string]string{}
					var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
					now := time.Now()
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						dealOutTradeNo[m.OrdNo] = m.OrdNo
						//outRequestNo := utils.OrderUUID(m.Uid)
						outRequestNo := ""
						centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
							OutTradeNo:   m.OrdNo,
							OutRequestNo: outRequestNo,
							Uid:          m.Uid,
							IdentityId:   m.IdentityId,
							RecordsId:    m.Id,
							State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
							Amount:       m.Amount,
							Memo:         "",
							CreateAt:     now.Format("2006-01-02 15:04:05"),
							UpdateAt:     now.Format("2006-01-02 15:04:05"),
						})
					}

					//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态 (ord_state)
					for _, vv := range dealOutTradeNo {
						err1 := JudgePackageOrdOrdState(vv)
						if err1 != nil {
							return err1
						}
					}

					//5、新增 `central_kitchen_for_school_user_refund_day` 数据
					centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
					centralKitchenForSchoolUserRefundDayDb.Set(0)
					_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
					if err != nil {
						return err
					}
				}
			}
		}
	}
	return
}

func CentralKitchenForSchoolBatchAskForLeaveByGrade(req md.CentralKitchenForSchoolBatchAskForLeaveReqByGrade) (err error) {
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	//1、查询学校
	enterprise, err1 := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err1 != nil {
		return
	}
	if enterprise == nil {
		return errors.New("未查询到id：【" + utils.IntToStr(req.EnterpriseId) + "】公司对应记录")
	}

	classDb := db.ClassDb{}
	var classWithUser *[]model.ClassWithUser
	for _, v := range req.GradeIds {
		classDb.Set(v)
		classes, err2 := classDb.FindClass()
		if err2 != nil {
			return err2
		}
		var classIds []int
		for _, vv := range *classes {
			classIds = append(classIds, vv.Id)
		}
		classWithUser, err = classWithUserDb.FindUserIdentity(classIds)
		if err != nil {
			return err
		}
		var identityIds []string
		for _, vv := range *classWithUser {
			identityIds = append(identityIds, utils.IntToStr(vv.UserIdentityId))
		}
		if len(identityIds) <= 0 {
			//无请假学生
			continue
		}
		for _, date := range req.Dates {
			//2、查询出所有 `central_kitchen_for_school_user_with_day` 记录
			var mm []model.CentralKitchenForSchoolUserWithDay
			centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
			centralKitchenForSchoolUserWithDayDb.Set(0)
			if req.IsBreakfast == 1 {
				err = centralKitchenForSchoolUserWithDayDb.Db.In("identity_id", identityIds).And("date =?", date).
					And("kind =?", enum2.CentralKitchenForSchoolUserWithDayKindForBreakfast).Find(&mm)
				if err != nil {
					return err
				}

				if len(mm) > 0 {
					var identityIdsV2 []string
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						identityIdsV2 = append(identityIdsV2, utils.IntToStr(m.IdentityId))
					}
					if len(identityIdsV2) <= 0 {
						//无请假学生
						continue
					}

					//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
					sql := "update central_kitchen_for_school_user_with_day set state = %d where identity_id In (%s) and date = '%s' and kind = %d and state = %d"
					idsStr := strings.Join(identityIdsV2, ",")
					sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr, date, enum2.CentralKitchenForSchoolUserWithDayKindForBreakfast, enum2.CentralKitchenForSchoolUserWithDayStateForWait)
					fmt.Println(sql)
					_, err = db.ExecuteOriginalSql(db.Db, sql)
					if err != nil {
						return err
					}

					//3、循环处理数据
					var dealOutTradeNo = map[string]string{}
					var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
					now := time.Now()
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						dealOutTradeNo[m.OrdNo] = m.OrdNo
						//outRequestNo := utils.OrderUUID(m.Uid)
						outRequestNo := ""
						centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
							OutTradeNo:   m.OrdNo,
							OutRequestNo: outRequestNo,
							Uid:          m.Uid,
							IdentityId:   m.IdentityId,
							RecordsId:    m.Id,
							State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
							Amount:       m.Amount,
							Memo:         "",
							CreateAt:     now.Format("2006-01-02 15:04:05"),
							UpdateAt:     now.Format("2006-01-02 15:04:05"),
						})
					}

					//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态 (ord_state)
					for _, vv := range dealOutTradeNo {
						err2 := JudgePackageOrdOrdState(vv)
						if err2 != nil {
							return err2
						}
					}

					//5、新增 `central_kitchen_for_school_user_refund_day` 数据
					centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
					centralKitchenForSchoolUserRefundDayDb.Set(0)
					_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
					if err != nil {
						return err
					}
				}
			}

			if req.IsLunch == 1 {
				err = centralKitchenForSchoolUserWithDayDb.Db.In("identity_id", identityIds).And("date =?", date).
					And("kind =?", enum2.CentralKitchenForSchoolUserWithDayKindForLunch).Find(&mm)
				if err != nil {
					return err
				}
				if len(mm) > 0 {
					var identityIdsV2 []string
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						identityIdsV2 = append(identityIdsV2, utils.IntToStr(m.IdentityId))
					}
					if len(identityIdsV2) <= 0 {
						//无请假学生
						continue
					}

					//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
					sql := "update central_kitchen_for_school_user_with_day set state = %d where identity_id In (%s) and date = '%s' and kind = %d and state = %d"
					idsStr := strings.Join(identityIdsV2, ",")
					sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr, date, enum2.CentralKitchenForSchoolUserWithDayKindForLunch, enum2.CentralKitchenForSchoolUserWithDayStateForWait)
					fmt.Println(sql)
					_, err = db.ExecuteOriginalSql(db.Db, sql)
					if err != nil {
						return err
					}

					//3、循环处理数据
					var dealOutTradeNo = map[string]string{}
					var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
					now := time.Now()
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						dealOutTradeNo[m.OrdNo] = m.OrdNo
						//outRequestNo := utils.OrderUUID(m.Uid)
						outRequestNo := ""
						centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
							OutTradeNo:   m.OrdNo,
							OutRequestNo: outRequestNo,
							Uid:          m.Uid,
							IdentityId:   m.IdentityId,
							RecordsId:    m.Id,
							State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
							Amount:       m.Amount,
							Memo:         "",
							CreateAt:     now.Format("2006-01-02 15:04:05"),
							UpdateAt:     now.Format("2006-01-02 15:04:05"),
						})
					}

					//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态 (ord_state)
					for _, vv := range dealOutTradeNo {
						err2 := JudgePackageOrdOrdState(vv)
						if err2 != nil {
							return err2
						}
					}

					//5、新增 `central_kitchen_for_school_user_refund_day` 数据
					centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
					centralKitchenForSchoolUserRefundDayDb.Set(0)
					_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
					if err != nil {
						return err
					}
				}
			}

			if req.IsDinner == 1 {
				err = centralKitchenForSchoolUserWithDayDb.Db.In("identity_id", identityIds).And("date =?", date).
					And("kind =?", enum2.CentralKitchenForSchoolUserWithDayKindForDinner).Find(&mm)
				if err != nil {
					return err
				}
				if len(mm) > 0 {
					var identityIdsV2 []string
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						identityIdsV2 = append(identityIdsV2, utils.IntToStr(m.IdentityId))
					}
					if len(identityIdsV2) <= 0 {
						//无请假学生
						continue
					}

					//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
					sql := "update central_kitchen_for_school_user_with_day set state = %d where identity_id In (%s) and date = '%s' and kind = %d and state = %d"
					idsStr := strings.Join(identityIdsV2, ",")
					sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr, date, enum2.CentralKitchenForSchoolUserWithDayKindForDinner, enum2.CentralKitchenForSchoolUserWithDayStateForWait)
					fmt.Println(sql)
					_, err = db.ExecuteOriginalSql(db.Db, sql)
					if err != nil {
						return err
					}

					//3、循环处理数据
					var dealOutTradeNo = map[string]string{}
					var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
					now := time.Now()
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						dealOutTradeNo[m.OrdNo] = m.OrdNo
						//outRequestNo := utils.OrderUUID(m.Uid)
						outRequestNo := ""
						centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
							OutTradeNo:   m.OrdNo,
							OutRequestNo: outRequestNo,
							Uid:          m.Uid,
							IdentityId:   m.IdentityId,
							RecordsId:    m.Id,
							State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
							Amount:       m.Amount,
							Memo:         "",
							CreateAt:     now.Format("2006-01-02 15:04:05"),
							UpdateAt:     now.Format("2006-01-02 15:04:05"),
						})
					}

					//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态 (ord_state)
					for _, vv := range dealOutTradeNo {
						err2 := JudgePackageOrdOrdState(vv)
						if err2 != nil {
							return err2
						}
					}

					//5、新增 `central_kitchen_for_school_user_refund_day` 数据
					centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
					centralKitchenForSchoolUserRefundDayDb.Set(0)
					_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
					if err != nil {
						return err
					}
				}
			}
		}
	}
	return
}

func CentralKitchenForSchoolBatchAskForLeaveByClass(req md.CentralKitchenForSchoolBatchAskForLeaveReqByClass) (err error) {
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	//1、查询学校
	enterprise, err1 := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err1 != nil {
		return
	}
	if enterprise == nil {
		return errors.New("未查询到id：【" + utils.IntToStr(req.EnterpriseId) + "】公司对应记录")
	}

	var classWithUser *[]model.ClassWithUser
	for _, v := range req.ClassIds {
		classWithUser, err = classWithUserDb.FindUserIdentity(v)
		if err != nil {
			return err
		}
		var identityIds []string
		for _, vv := range *classWithUser {
			identityIds = append(identityIds, utils.IntToStr(vv.UserIdentityId))
		}
		if len(identityIds) <= 0 {
			//无请假学生
			continue
		}

		for _, date := range req.Dates {
			//2、查询出所有 `central_kitchen_for_school_user_with_day` 记录
			var mm []model.CentralKitchenForSchoolUserWithDay
			centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
			centralKitchenForSchoolUserWithDayDb.Set(0)
			if req.IsBreakfast == 1 {
				err = centralKitchenForSchoolUserWithDayDb.Db.In("identity_id", identityIds).And("date =?", date).
					And("kind =?", enum2.CentralKitchenForSchoolUserWithDayKindForBreakfast).Find(&mm)
				if err != nil {
					return err
				}
				if len(mm) > 0 {
					var identityIdsV2 []string
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						identityIdsV2 = append(identityIdsV2, utils.IntToStr(m.IdentityId))
					}
					if len(identityIdsV2) <= 0 {
						//无请假学生
						continue
					}

					//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
					sql := "update central_kitchen_for_school_user_with_day set state = %d where identity_id In (%s) and date = '%s' and kind = %d and state = %d"
					idsStr := strings.Join(identityIdsV2, ",")
					sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr, date, enum2.CentralKitchenForSchoolUserWithDayKindForBreakfast, enum2.CentralKitchenForSchoolUserWithDayStateForWait)
					fmt.Println(sql)
					_, err = db.ExecuteOriginalSql(db.Db, sql)
					if err != nil {
						return err
					}

					//3、循环处理数据
					var dealOutTradeNo = map[string]string{}
					var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
					now := time.Now()
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						dealOutTradeNo[m.OrdNo] = m.OrdNo
						//outRequestNo := utils.OrderUUID(m.Uid)
						outRequestNo := ""
						centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
							OutTradeNo:   m.OrdNo,
							OutRequestNo: outRequestNo,
							Uid:          m.Uid,
							IdentityId:   m.IdentityId,
							RecordsId:    m.Id,
							State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
							Amount:       m.Amount,
							Memo:         "",
							CreateAt:     now.Format("2006-01-02 15:04:05"),
							UpdateAt:     now.Format("2006-01-02 15:04:05"),
						})
					}

					//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态 (ord_state)
					for _, vv := range dealOutTradeNo {
						err2 := JudgePackageOrdOrdState(vv)
						if err2 != nil {
							return err2
						}
					}

					//5、新增 `central_kitchen_for_school_user_refund_day` 数据
					centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
					centralKitchenForSchoolUserRefundDayDb.Set(0)
					_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
					if err != nil {
						return err
					}
				}
			}

			if req.IsLunch == 1 {
				err = centralKitchenForSchoolUserWithDayDb.Db.In("identity_id", identityIds).And("date =?", date).
					And("kind =?", enum2.CentralKitchenForSchoolUserWithDayKindForLunch).Find(&mm)
				if err != nil {
					return err
				}
				if len(mm) > 0 {
					var identityIdsV2 []string
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						identityIdsV2 = append(identityIdsV2, utils.IntToStr(m.IdentityId))
					}
					if len(identityIdsV2) <= 0 {
						//无请假学生
						continue
					}

					//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
					sql := "update central_kitchen_for_school_user_with_day set state = %d where identity_id In (%s) and date = '%s' and kind = %d and state = %d"
					idsStr := strings.Join(identityIdsV2, ",")
					sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr, date, enum2.CentralKitchenForSchoolUserWithDayKindForLunch, enum2.CentralKitchenForSchoolUserWithDayStateForWait)
					fmt.Println(sql)
					_, err = db.ExecuteOriginalSql(db.Db, sql)
					if err != nil {
						return err
					}

					//3、循环处理数据
					var dealOutTradeNo = map[string]string{}
					var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
					now := time.Now()
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						dealOutTradeNo[m.OrdNo] = m.OrdNo
						//outRequestNo := utils.OrderUUID(m.Uid)
						outRequestNo := ""
						centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
							OutTradeNo:   m.OrdNo,
							OutRequestNo: outRequestNo,
							Uid:          m.Uid,
							IdentityId:   m.IdentityId,
							RecordsId:    m.Id,
							State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
							Amount:       m.Amount,
							Memo:         "",
							CreateAt:     now.Format("2006-01-02 15:04:05"),
							UpdateAt:     now.Format("2006-01-02 15:04:05"),
						})
					}

					//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态 (ord_state)
					for _, vv := range dealOutTradeNo {
						err2 := JudgePackageOrdOrdState(vv)
						if err2 != nil {
							return err2
						}
					}

					//5、新增 `central_kitchen_for_school_user_refund_day` 数据
					centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
					centralKitchenForSchoolUserRefundDayDb.Set(0)
					_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
					if err != nil {
						return err
					}
				}
			}

			if req.IsDinner == 1 {
				err = centralKitchenForSchoolUserWithDayDb.Db.In("identity_id", identityIds).And("date =?", date).
					And("kind =?", enum2.CentralKitchenForSchoolUserWithDayKindForDinner).Find(&mm)
				if err != nil {
					return err
				}
				if len(mm) > 0 {
					var identityIdsV2 []string
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						identityIdsV2 = append(identityIdsV2, utils.IntToStr(m.IdentityId))
					}
					if len(identityIdsV2) <= 0 {
						//无请假学生
						continue
					}

					//2、更改 `central_kitchen_for_school_user_with_day` 的 state 为 退款中
					sql := "update central_kitchen_for_school_user_with_day set state = %d where identity_id In (%s) and date = '%s' and kind = %d and state =%d"
					idsStr := strings.Join(identityIdsV2, ",")
					sql = fmt.Sprintf(sql, enum2.CentralKitchenForSchoolUserWithDayStateForCanceling, idsStr, date, enum2.CentralKitchenForSchoolUserWithDayKindForDinner, enum2.CentralKitchenForSchoolUserWithDayStateForWait)
					fmt.Println(sql)
					_, err = db.ExecuteOriginalSql(db.Db, sql)
					if err != nil {
						return err
					}

					//3、循环处理数据
					var dealOutTradeNo = map[string]string{}
					var centralKitchenForSchoolUserRefundDays []*model.CentralKitchenForSchoolUserRefundDay
					now := time.Now()
					for _, m := range mm {
						if m.State != enum2.CentralKitchenForSchoolUserWithDayStateForWait {
							continue
						}
						dealOutTradeNo[m.OrdNo] = m.OrdNo
						//outRequestNo := utils.OrderUUID(m.Uid)
						outRequestNo := ""
						centralKitchenForSchoolUserRefundDays = append(centralKitchenForSchoolUserRefundDays, &model.CentralKitchenForSchoolUserRefundDay{
							OutTradeNo:   m.OrdNo,
							OutRequestNo: outRequestNo,
							Uid:          m.Uid,
							IdentityId:   m.IdentityId,
							RecordsId:    m.Id,
							State:        enum2.CentralKitchenForSchoolUserRefundDayStateForAuditing,
							Amount:       m.Amount,
							Memo:         "",
							CreateAt:     now.Format("2006-01-02 15:04:05"),
							UpdateAt:     now.Format("2006-01-02 15:04:05"),
						})
					}

					//4、处理 `central_kitchen_for_school_package_ord` 的 订单状态 (ord_state)
					for _, vv := range dealOutTradeNo {
						err2 := JudgePackageOrdOrdState(vv)
						if err2 != nil {
							return err2
						}
					}

					//5、新增 `central_kitchen_for_school_user_refund_day` 数据
					centralKitchenForSchoolUserRefundDayDb := db.CentralKitchenForSchoolUserRefundDayDb{}
					centralKitchenForSchoolUserRefundDayDb.Set(0)
					_, err = centralKitchenForSchoolUserRefundDayDb.BatchAddCentralKitchenForSchoolUserRefundDays(centralKitchenForSchoolUserRefundDays)
					if err != nil {
						return err
					}
				}
			}
		}
	}
	return
}

// JudgePackageOrdOrdState 判断订单状态
func JudgePackageOrdOrdState(outTradeNo string) (err error) {
	centralKitchenForSchoolPackageOrd := db.CentralKitchenForSchoolPackageOrd{}
	centralKitchenForSchoolPackageOrd.Set(outTradeNo)
	ord, err := centralKitchenForSchoolPackageOrd.GetCentralKitchenForSchoolPackageOrd()
	if err != nil {
		return
	}
	var ordState, oldOrdState int
	oldOrdState = ord.OrdState
	ordState = oldOrdState

	var m model.CentralKitchenForSchoolUserWithDay
	total, err := db.Db.Where("ord_no =?", outTradeNo).Count(&m)
	if err != nil {
		return
	}

	//1、判断是否有 `待就餐`
	count1, err := db.Db.Where("ord_no =?", outTradeNo).And("state =?", enum2.CentralKitchenForSchoolUserWithDayStateForWait).Count(&m)
	if err != nil {
		return
	}
	if count1 == 0 {
		ordState = enum2.CentralKitchenForSchoolPackageOrdOrdStateForComplete
	} else {
		ordState = enum2.CentralKitchenForSchoolPackageOrdOrdStateForSuccess
	}

	//2、判断是否有 `已退款` / `部分退款`
	count2, err := db.Db.Where("ord_no =?", outTradeNo).And("state =?", enum2.CentralKitchenForSchoolUserWithDayStateForCancel).Count(&m)
	if err != nil {
		return
	}
	//if count2 > 0 && count2 < total && count1 > 0 {
	if count2 > 0 && count2 < total {
		ordState = enum2.CentralKitchenForSchoolPackageOrdOrdStateForPartRefunded
	}
	if count2 > 0 && count2 == total {
		ordState = enum2.CentralKitchenForSchoolPackageOrdOrdStateForRefunded
	}

	//3、判断是否有 `退款中`
	count3, err := db.Db.Where("ord_no =?", outTradeNo).And("state =?", enum2.CentralKitchenForSchoolUserWithDayStateForCanceling).Count(&m)
	if err != nil {
		return
	}
	if count3 > 0 {
		ordState = enum2.CentralKitchenForSchoolPackageOrdOrdStateForRefunding
	}

	if ordState != oldOrdState {
		ord.OrdState = ordState
		_, err2 := centralKitchenForSchoolPackageOrd.CentralKitchenForSchoolPackageOrdUpdate(ord, "ord_state")
		if err2 != nil {
			return err2
		}
	}
	return
}

func CentralKitchenForSchoolGradeList(req md.CentralKitchenForSchoolGradeListReq) (m []*model.Grade, count int64, err error) {
	sess := db.Db.Where("enterprise_id =?", req.EnterpriseId)
	if req.Name != "" {
		sess.And("name like ?", "%"+req.Name+"%")
	}
	count, err = sess.Asc("id").Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}
	return
}

func CentralKitchenForSchoolClassList(req md.CentralKitchenForSchoolClassListReq) (m []*model.Class, count int64, err error) {
	sess := db.Db.Where("enterprise_id =?", req.EnterpriseId)
	if req.Name != "" {
		sess.And("name like ?", "%"+req.Name+"%")
	}
	if req.GradeId != 0 {
		sess.And("grade_id = ?", req.GradeId)
	}
	count, err = sess.Asc("id").Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}
	return
}
